function varargout = nic_rsdd_sliceViewer_ParaSel(varargin)
% NIC_RSDD_SLICEVIEWER_PARASEL M-file for nic_rsdd_sliceViewer_ParaSel.fig
%      NIC_RSDD_SLICEVIEWER_PARASEL, by itself, creates a new NIC_RSDD_SLICEVIEWER_PARASEL or raises the existing
%      singleton*.
%
%      H = NIC_RSDD_SLICEVIEWER_PARASEL returns the handle to a new NIC_RSDD_SLICEVIEWER_PARASEL or the handle to
%      the existing singleton*.
%
%      NIC_RSDD_SLICEVIEWER_PARASEL('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in NIC_RSDD_SLICEVIEWER_PARASEL.M with the given input arguments.
%
%      NIC_RSDD_SLICEVIEWER_PARASEL('Property','Value',...) creates a new NIC_RSDD_SLICEVIEWER_PARASEL or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before nic_rsdd_sliceViewer_ParaSel_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to nic_rsdd_sliceViewer_ParaSel_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help nic_rsdd_sliceViewer_ParaSel

% Last Modified by GUIDE v2.5 22-Sep-2009 13:18:23

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @nic_rsdd_sliceViewer_ParaSel_OpeningFcn, ...
                   'gui_OutputFcn',  @nic_rsdd_sliceViewer_ParaSel_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before nic_rsdd_sliceViewer_ParaSel is made visible.
function nic_rsdd_sliceViewer_ParaSel_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to nic_rsdd_sliceViewer_ParaSel (see VARARGIN)

% Choose default command line output for nic_rsdd_sliceViewer_ParaSel
handles.output = hObject;

global cfg;
cfg.returnValue=2;
cfg.threshold=1.0;
handles.cfg=cfg;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes nic_rsdd_sliceViewer_ParaSel wait for user response (see UIRESUME)
uiwait(handles.SliceViewerPFig);

if(ishandle(handles.output))
    delete(handles.output);
end


% --- Outputs from this function are returned to the command line.
function varargout = nic_rsdd_sliceViewer_ParaSel_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
% varargout{1} = handles.output;
if(isfield(handles,'cfg'))
    varargout{1} = handles.cfg;
else
    global cfg;
    varargout{1} = cfg;
    clear global cfg;
end

% --- Executes on selection change in imageValuesHdl.
function imageValuesHdl_Callback(hObject, eventdata, handles)
% hObject    handle to imageValuesHdl (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns imageValuesHdl contents as cell array
%        contents{get(hObject,'Value')} returns selected item from imageValuesHdl


% --- Executes during object creation, after setting all properties.
function imageValuesHdl_CreateFcn(hObject, eventdata, handles)
% hObject    handle to imageValuesHdl (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function thresholdValueHdl_Callback(hObject, eventdata, handles)
% hObject    handle to thresholdValueHdl (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of thresholdValueHdl as text
%        str2double(get(hObject,'String')) returns contents of thresholdValueHdl as a double


% --- Executes during object creation, after setting all properties.
function thresholdValueHdl_CreateFcn(hObject, eventdata, handles)
% hObject    handle to thresholdValueHdl (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in ButOK.
function ButOK_Callback(hObject, eventdata, handles)
% hObject    handle to ButOK (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
imagev=get(handles.imageValuesHdl,'Value');
handles.cfg.threshold=str2num(get(handles.thresholdValueHdl,'String'));
if(imagev==1)
    imagev=2;
elseif(imagev==2)
    imagev=1;
end
handles.cfg.returnValue=imagev;

global cfg;
cfg=handles.cfg;

uiresume(handles.SliceViewerPFig);

if(ishandle(handles.output))
    delete(handles.output);
end

% --- Executes on button press in ButCancel.
function ButCancel_Callback(hObject, eventdata, handles)
% hObject    handle to ButCancel (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

uiresume(handles.SliceViewerPFig);
if(ishandle(handles.output))
    delete(handles.output);
end
